@@ -115,6 +115,10 @@ MainWindow::MainWindow(QWidget *parent)
 
     if (Settings::rememberSessions()) // give some time to create and show the window first
         QTimer::singleShot(100, this, SLOT(restoreOpenSessions()));
+
+    if (Settings::systemTrayIcon()) {
+        m_systemTrayIcon = new SystemTrayIcon(this);
+    }
 }
 
 MainWindow::~MainWindow()
@@ -305,6 +309,7 @@ void MainWindow::newConnection(const QUrl &newUrl, bool switchFullscreenWhenConn
     connect(view, SIGNAL(framebufferSizeChanged(int, int)), this, SLOT(resizeTabWidget(int, int)));
     connect(view, SIGNAL(statusChanged(RemoteView::RemoteStatus)), this, SLOT(statusChanged(RemoteView::RemoteStatus)));
     connect(view, SIGNAL(disconnected()), this, SLOT(disconnectHost()));
+    connect(view, SIGNAL(errorMessage(const QString &, const QString &)), this, SLOT(handleViewError(const QString &, const QString &)));
 
     QScrollArea *scrollArea = createScrollArea(m_tabWidget, view);
 
@@ -372,6 +377,9 @@ void MainWindow::resizeTabWidget(int w, int h)
 
     const QSize viewSize = QSize(w, h);
     QScreen *currentScreen = QGuiApplication::screenAt(geometry().center());
+    if (!currentScreen) {
+        return;
+    }
 
     if (Settings::fullscreenOnConnect()) {
         const QSize screenSize = currentScreen->availableGeometry().size();
@@ -1224,3 +1232,8 @@ void MainWindow::createDockWidget()
     m_remoteDesktopsDockWidget->setWidget(remoteDesktopsDockLayoutWidget);
     addDockWidget(Qt::LeftDockWidgetArea, m_remoteDesktopsDockWidget);
 }
+
+void MainWindow::handleViewError(const QString &title, const QString &message)
+{
+    KMessageBox::error(this, message, title);
+}
