@@ -17,14 +17,11 @@
 
 #ifdef QTONLY
 #include <QInputDialog>
-#include <QMessageBox>
-#define KMessageBox QMessageBox
 #define error(parent, message, caption) critical(parent, caption, message)
 #else
 #include "settings.h"
 #include <KActionCollection>
 #include <KMainWindow>
-#include <KMessageBox>
 #include <KPasswordDialog>
 #include <KXMLGUIClient>
 #endif
@@ -380,8 +377,6 @@ void VncView::outputErrorMessage(const QString &message)
 
     startQuitting();
 
-    KMessageBox::error(this, message, i18n("VNC failure"));
-
     Q_EMIT errorMessage(i18n("VNC failure"), message);
 }
 
@@ -391,8 +386,6 @@ void VncView::sshErrorMessage(const QString &message)
 
     startQuitting();
 
-    KMessageBox::error(this, message, i18n("SSH Tunnel failure"));
-
     Q_EMIT errorMessage(i18n("SSH Tunnel failure"), message);
 }
 
@@ -419,6 +412,7 @@ void VncView::updateImage(int x, int y, int w, int h)
         setCursor(((m_localCursorState == CursorOn) || m_forceLocalCursor) ? localDefaultCursor() : Qt::BlankCursor);
 
         setFocusPolicy(Qt::WheelFocus);
+        setFocus();
         setStatus(Connected);
         Q_EMIT connected();
 
